use async_trait::async_trait;
use sea_orm_migration::{prelude::*, schema::*};

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(Locks::Table)
                    .if_not_exists()
                    .col(pk_auto(Locks::Id))
                    .col(string(Locks::LockType))
                    .col(string(Locks::LockResource))
                    .col(string_null(Locks::LockOwner))
                    .col(text_null(Locks::LockReason))
                    .to_owned())
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(
                Table::drop()
                    .table(Locks::Table)
                    .to_owned())
            .await
    }
}

#[derive(DeriveIden)]
enum Locks {
    Table,
    Id,
    LockType,
    LockResource,
    LockOwner,
    LockReason
}
