use async_trait::async_trait;
use sea_orm_migration::{prelude::*, schema::*};

#[derive(DeriveMigrationName)]
pub struct Migration;

#[async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .create_table(
                Table::create()
                    .table(Volumes::Table)
                    .if_not_exists()
                    .col(pk_auto(Volumes::VolumeId))
                    .col(string(Volumes::Name))
                    .col(big_unsigned(Volumes::SizeInBytes))
                    .col(integer(Volumes::PveNodeId))
                    .col(string_null(Volumes::MountpointIdentifier))
                    .col(string_null(Volumes::MountpointHost))
                    .col(string_null(Volumes::Mountpoint))
                    .col(string_null(Volumes::DiskName))
                    .to_owned())
            .await
    }

    async fn down(&self, manager: &SchemaManager) -> Result<(), DbErr> {
        manager
            .drop_table(
                Table::drop()
                    .table(Volumes::Table)
                    .to_owned())
            .await
    }
}

#[derive(DeriveIden)]
enum Volumes {
    Table,
    VolumeId,
    Name,
    SizeInBytes,
    PveNodeId,
    MountpointIdentifier,
    MountpointHost,
    Mountpoint,
    DiskName,
}
